#pragma once

#include "CommonType.h"

typedef struct ORG_MEMBER_DATA
{
	NE_MEMBER_DATA	neMemberData;
	GTUserStatusType eStatus;	//  
	NTIPTStatusType eIPTStatus;	// IPT 
} ORG_MEMBER_DATA;

class IWorkGroupModel
{
public:
	IWorkGroupModel() {};
	virtual ~IWorkGroupModel() {};

	virtual void AddMember(const NE_MEMBER_DATA& data) = 0;
	virtual const std::vector<ORG_MEMBER_DATA> GetMemberVector() const = 0;
	virtual const NE_MEMBER_DATA GetMember(int index) = 0;

	virtual void AddWorkGroup(const GT_ORG_GROUP_DATA& data) = 0;
	virtual const std::vector<GT_ORG_GROUP_DATA> GetWorkGroupVector() const = 0;

	virtual void AddOrgGroup(const GT_ORG_GROUP_DATA& data) = 0;
	virtual const std::vector<GT_ORG_GROUP_DATA> GetOrgGroupVector() const = 0;

	virtual void ClearMembers() = 0;
	virtual void ClearGroups() = 0;

	virtual void UpdateMemberStatus(LPCWSTR strUserID, GTUserStatusType eUserStatus) = 0;
	virtual void UpdateMemberIPTStatus(LPCWSTR strUserID, NTIPTStatusType eUserIPTStatus) = 0;
	virtual GTUserStatusType GetMemberStatus(LPCWSTR strUserID) = 0;
	virtual NTIPTStatusType GetMemberIPTStatus(LPCWSTR strUserID) = 0;

	virtual void AddSelectdUser( const NE_MEMBER_DATA& data ) = 0;
	virtual const std::vector<ORG_MEMBER_DATA> GetSelectedUserVector() const = 0;
	virtual void ClearSelectedUserVector() = 0;
};

class WorkGroupModel : public IWorkGroupModel
{
public:
	WorkGroupModel(void);
	~WorkGroupModel(void);

	void AddBuddyMember(const NE_MEMBER_DATA& data, GTUserStatusType eUserStatus, NTIPTStatusType eIPTStatus);
	void AddMember(const NE_MEMBER_DATA& data);
	const std::vector<ORG_MEMBER_DATA> GetMemberVector() const;
	const NE_MEMBER_DATA GetMember(int index);
	const NE_MEMBER_DATA GetMember(LPCWSTR strUserID);
	void AddWorkGroup(const GT_ORG_GROUP_DATA& data);
	const std::vector<GT_ORG_GROUP_DATA> GetWorkGroupVector() const;

	void AddOrgGroup(const GT_ORG_GROUP_DATA& data);
	const std::vector<GT_ORG_GROUP_DATA> GetOrgGroupVector() const;

	void Clear(BOOL bDeteleAllData = FALSE);
	void ClearMembers();
	void ClearGroups();

	void SetSearchTotal(int nSearchTotal)	{ m_nSearchTotal = nSearchTotal; }
	void SetSearchPage(int nSearchPage)		{ m_nSearchPage = nSearchPage; }
	int GetSearchTotal()	{ return m_nSearchTotal; }	// not a page. just count
	int GetSearchPage()		{ return m_nSearchPage; }

	void UpdateMemberStatus(LPCWSTR strUserID, GTUserStatusType eUserStatus);
	void UpdateMemberIPTStatus(LPCWSTR strUserID, NTIPTStatusType eUserIPTStatus);
	GTUserStatusType GetMemberStatus(LPCWSTR strUserID);
	NTIPTStatusType GetMemberIPTStatus(LPCWSTR strUserID);

	void AddSelectdUser( const NE_MEMBER_DATA& data );
	const std::vector<ORG_MEMBER_DATA> GetSelectedUserVector() const;
	void ClearSelectedUserVector();
	WSTRING GetMemberWorkStatus( LPCWSTR strUserID );

private:
	int m_nSearchTotal;		// ˻   Ǽ(˻  쿡 ϴ)
	int m_nSearchPage;		// ˻ 

	std::map<CString, ORG_MEMBER_DATA> m_mapAllMember;
	std::vector<ORG_MEMBER_DATA> m_memberVector;		//   
	std::vector<ORG_MEMBER_DATA> m_selectedUserVector;	//  ߰â  

	std::vector<GT_ORG_GROUP_DATA> m_workGroupVector;	// ׷ 
	std::vector<GT_ORG_GROUP_DATA> m_orgGroupVector;	//  
	
	std::map<std::wstring, int> m_memberStatus;
	std::map<std::wstring, int> m_memberIPTStatus;
};
